@@ -2,17 +2,17 @@
 
 package main;
 
-our $config;
+our $cfg;
 our $dbh;
 
 package EB::Report::Debcrd;
 
-# RCS Id          : $Id: Debcrd.pm,v 1.16 2008/03/05 21:36:37 jv Exp $
+# RCS Id          : $Id: Debcrd.pm,v 1.17 2008/08/24 15:33:44 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Wed Dec 28 16:08:10 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Wed Mar  5 22:27:17 2008
-# Update Count    : 185
+# Last Modified On: Sun Aug 24 17:33:29 2008
+# Update Count    : 186
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -20,7 +20,7 @@ package EB::Report::Debcrd;
 use strict;
 use warnings;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.16 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.17 $ =~ /(\d+)/g;
 
 ################ The Process ################
 
