@@ -1,11 +1,11 @@
 #! perl
 
-# RCS Id          : $Id: Opening.pm,v 1.39 2008/04/09 21:03:57 jv Exp $
+# RCS Id          : $Id: Opening.pm,v 1.41 2008/07/19 16:49:56 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Tue Aug 30 09:49:11 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Wed Apr  2 21:27:34 2008
-# Update Count    : 268
+# Last Modified On: Thu May  1 17:55:43 2008
+# Update Count    : 290
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -18,7 +18,7 @@ package EB::Tools::Opening;
 use strict;
 use warnings;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.39 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.41 $ =~ /(\d+)/g;
 
 use EB;
 use EB::Format;
@@ -135,12 +135,17 @@ sub set_balans {
 }
 
 sub set_relatie {
+
+    # adm_relatie verkoop:2000:31 2000-12-30 ACME Cursus 1000
+    # adm_relatie 2000-12-31 Cons deb ACME 1000
+
     return shellhelp() unless @_ == 6;
     my $self = shift;
     my ($date, $desc, $type, $code, $amt);
     my ($dbk, $bky, $nr);
 
     if ( $_[0] =~ /^(\w+):(\w+):(\d+)$/ ) {
+	# adm_relatie verkoop:2000:31 2000-12-30 ACME Cursus 1000
 	($dbk, $bky, $nr) = ($1, $2, $3);
 	shift;
 	($date, $code, $desc, $amt) = @_;
@@ -150,6 +155,7 @@ sub set_relatie {
 	$type = $t == DBKTYPE_VERKOOP;
     }
     else {
+	# adm_relatie 2000-12-31 Cons deb ACME 1000
 	($date, $desc, $type, $code, $amt) = @_;
 	return _T("Relatietype moet \"deb\" of \"crd\" zijn")."\n"
 	  unless $type =~ /^crd|deb$/;
@@ -166,26 +172,35 @@ sub set_relatie {
     $bky = substr($date, 0, 4) unless defined $bky;
 
     my $acct;
+    my $sth;
     unless ( defined($dbk) ) {
-	my $sth = $dbh->sql_exec("SELECT min(dbk_id)".
-				 " FROM Dagboeken".
-				 " WHERE dbk_type = ?",
-				 $type ? DBKTYPE_VERKOOP : DBKTYPE_INKOOP);
-	$dbk = $sth->fetchrow_arrayref->[0];
+	$sth = $dbh->sql_exec("SELECT rel_code, rel_ledger".
+			      " FROM Relaties".
+			      " WHERE UPPER(rel_code) = ?".
+			      " AND ".($type ? "" : "NOT ")." rel_debcrd",
+			      uc($code));
+	my $rr = $sth->fetch;
+	return __x("Onbekende relatie: {rel}", rel => $code)."\n"
+	  unless defined $rr;
+	($code, $dbk) = @$rr;
 	$sth->finish;
+	$sth = $dbh->sql_exec("SELECT dbk_id, dbk_acc_id".
+			      " FROM Dagboeken".
+			      " WHERE dbk_id = ?",
+			      $dbk);
     }
     else {
-	my $sth = $dbh->sql_exec("SELECT dbk_id, dbk_acc_id".
-				 " FROM Dagboeken".
-				 " WHERE UPPER(dbk_desc) = ?",
-				 uc($dbk));
-	($dbk, $acct) = @{$sth->fetch};
+	$sth = $dbh->sql_exec("SELECT dbk_id, dbk_acc_id".
+			      " FROM Dagboeken".
+			      " WHERE UPPER(dbk_desc) = ?",
+			      uc($dbk));
     }
+    ($dbk, $acct) = @{$sth->fetch};
 
     my $rr = $dbh->do("SELECT rel_code FROM Relaties" .
-			   " WHERE UPPER(rel_code) = ?" .
-			   "  AND " . ($type ? "" : "NOT ") . "rel_debcrd" .
-		           "  AND rel_ledger = ?",
+		      " WHERE UPPER(rel_code) = ?" .
+		      "  AND " . ($type ? "" : "NOT ") . "rel_debcrd" .
+		      "  AND rel_ledger = ?",
 		      uc($code), $dbk);
 
     return __x("Onbekende relatie: {rel}", rel => $code)."\n"
@@ -443,7 +458,6 @@ sub open {
 	my $dbk_verkoop;
 	foreach my $r ( @{$o->{relatie}} ) {
 	    my ($bky, $nr, $date, $desc, $debcrd, $code, $acct, $amt) = @$r;
-
 	    $nr = $dbh->get_sequence("bsk_nr_0_seq") unless defined $nr;
 
 	    my ($dagboek) = @{$dbh->do("SELECT dbk_id".
